pub struct InterruptAttributorGetInterruptInfoResponse {
pub device_name: String,
pub component_token: Option<Event>,
}Fields
device_name: Stringcomponent_token: Option<Event>Trait Implementations
Sourceimpl<___E> Encode<InterruptAttributorGetInterruptInfoResponse<'static>, ___E> for InterruptAttributorGetInterruptInfoResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
impl<___E> Encode<InterruptAttributorGetInterruptInfoResponse<'static>, ___E> for InterruptAttributorGetInterruptInfoResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InterruptAttributorGetInterruptInfoResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InterruptAttributorGetInterruptInfoResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, InterruptAttributorGetInterruptInfoResponse<'static>>, ___E> for InterruptAttributorGetInterruptInfoResponsewhere
___E: Encoder + ?Sized,
InterruptAttributorGetInterruptInfoResponse: Encode<InterruptAttributorGetInterruptInfoResponse<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, InterruptAttributorGetInterruptInfoResponse<'static>>, ___E> for InterruptAttributorGetInterruptInfoResponsewhere
___E: Encoder + ?Sized,
InterruptAttributorGetInterruptInfoResponse: Encode<InterruptAttributorGetInterruptInfoResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, InterruptAttributorGetInterruptInfoResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, InterruptAttributorGetInterruptInfoResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<InterruptAttributorGetInterruptInfoResponse<'de>> for InterruptAttributorGetInterruptInfoResponse
impl<'de> FromWire<InterruptAttributorGetInterruptInfoResponse<'de>> for InterruptAttributorGetInterruptInfoResponse
Sourcefn from_wire(wire: InterruptAttributorGetInterruptInfoResponse<'de>) -> Self
fn from_wire(wire: InterruptAttributorGetInterruptInfoResponse<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl PartialEq for InterruptAttributorGetInterruptInfoResponse
impl PartialEq for InterruptAttributorGetInterruptInfoResponse
Sourcefn eq(&self, other: &InterruptAttributorGetInterruptInfoResponse) -> bool
fn eq(&self, other: &InterruptAttributorGetInterruptInfoResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for InterruptAttributorGetInterruptInfoResponse