pub struct PlatformBusRegisterIommuRequest {
pub iommu_id: u32,
pub iommu: Iommu,
}Fields
iommu_id: u32iommu: IommuTrait Implementations
Sourceimpl Clone for PlatformBusRegisterIommuRequest
impl Clone for PlatformBusRegisterIommuRequest
Sourcefn clone(&self) -> PlatformBusRegisterIommuRequest
fn clone(&self) -> PlatformBusRegisterIommuRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for PlatformBusRegisterIommuRequest
Sourceimpl<___E> Encode<PlatformBusRegisterIommuRequest<'static>, ___E> for PlatformBusRegisterIommuRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
impl<___E> Encode<PlatformBusRegisterIommuRequest<'static>, ___E> for PlatformBusRegisterIommuRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PlatformBusRegisterIommuRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PlatformBusRegisterIommuRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, PlatformBusRegisterIommuRequest<'static>>, ___E> for PlatformBusRegisterIommuRequestwhere
___E: Encoder + ?Sized,
PlatformBusRegisterIommuRequest: Encode<PlatformBusRegisterIommuRequest<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, PlatformBusRegisterIommuRequest<'static>>, ___E> for PlatformBusRegisterIommuRequestwhere
___E: Encoder + ?Sized,
PlatformBusRegisterIommuRequest: Encode<PlatformBusRegisterIommuRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PlatformBusRegisterIommuRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PlatformBusRegisterIommuRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for PlatformBusRegisterIommuRequest
Sourceimpl<'de> FromWire<PlatformBusRegisterIommuRequest<'de>> for PlatformBusRegisterIommuRequest
impl<'de> FromWire<PlatformBusRegisterIommuRequest<'de>> for PlatformBusRegisterIommuRequest
Sourcefn from_wire(wire: PlatformBusRegisterIommuRequest<'de>) -> Self
fn from_wire(wire: PlatformBusRegisterIommuRequest<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl Ord for PlatformBusRegisterIommuRequest
impl Ord for PlatformBusRegisterIommuRequest
Sourcefn cmp(&self, other: &PlatformBusRegisterIommuRequest) -> Ordering
fn cmp(&self, other: &PlatformBusRegisterIommuRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PlatformBusRegisterIommuRequest
impl PartialEq for PlatformBusRegisterIommuRequest
Sourcefn eq(&self, other: &PlatformBusRegisterIommuRequest) -> bool
fn eq(&self, other: &PlatformBusRegisterIommuRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for PlatformBusRegisterIommuRequest
impl PartialOrd for PlatformBusRegisterIommuRequest
impl StructuralPartialEq for PlatformBusRegisterIommuRequest