#[repr(C)]pub struct SysSuspendCallbackResponse {
pub out_status: Status,
}Fields
out_status: StatusTrait Implementations
Sourceimpl Clone for SysSuspendCallbackResponse
impl Clone for SysSuspendCallbackResponse
Sourcefn clone(&self) -> SysSuspendCallbackResponse
fn clone(&self) -> SysSuspendCallbackResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for SysSuspendCallbackResponse
Sourceimpl Debug for SysSuspendCallbackResponse
impl Debug for SysSuspendCallbackResponse
Sourceimpl<___E> Encode<SysSuspendCallbackResponse, ___E> for SysSuspendCallbackResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<SysSuspendCallbackResponse, ___E> for SysSuspendCallbackResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<SysSuspendCallbackResponse, SysSuspendCallbackResponse>
const COPY_OPTIMIZATION: CopyOptimization<SysSuspendCallbackResponse, SysSuspendCallbackResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SysSuspendCallbackResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SysSuspendCallbackResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<SysSuspendCallbackResponse, ___E> for &'a SysSuspendCallbackResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<SysSuspendCallbackResponse, ___E> for &'a SysSuspendCallbackResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SysSuspendCallbackResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SysSuspendCallbackResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, SysSuspendCallbackResponse>, ___E> for SysSuspendCallbackResponse
impl<___E> EncodeOption<Box<'static, SysSuspendCallbackResponse>, ___E> for SysSuspendCallbackResponse
Sourcefn encode_option(
this: Option<SysSuspendCallbackResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SysSuspendCallbackResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<SysSuspendCallbackResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SysSuspendCallbackResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, SysSuspendCallbackResponse>, ___E> for &'a SysSuspendCallbackResponsewhere
___E: Encoder + ?Sized,
&'a SysSuspendCallbackResponse: Encode<SysSuspendCallbackResponse, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, SysSuspendCallbackResponse>, ___E> for &'a SysSuspendCallbackResponsewhere
___E: Encoder + ?Sized,
&'a SysSuspendCallbackResponse: Encode<SysSuspendCallbackResponse, ___E>,
Sourcefn encode_option(
this: Option<&'a SysSuspendCallbackResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SysSuspendCallbackResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a SysSuspendCallbackResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SysSuspendCallbackResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for SysSuspendCallbackResponse
Sourceimpl FromWire<SysSuspendCallbackResponse> for SysSuspendCallbackResponse
impl FromWire<SysSuspendCallbackResponse> for SysSuspendCallbackResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<SysSuspendCallbackResponse, SysSuspendCallbackResponse>
const COPY_OPTIMIZATION: CopyOptimization<SysSuspendCallbackResponse, SysSuspendCallbackResponse>
Sourcefn from_wire(wire: SysSuspendCallbackResponse) -> SysSuspendCallbackResponse
fn from_wire(wire: SysSuspendCallbackResponse) -> SysSuspendCallbackResponse
Converts the given owned value to this type.
Sourceimpl FromWireRef<SysSuspendCallbackResponse> for SysSuspendCallbackResponse
impl FromWireRef<SysSuspendCallbackResponse> for SysSuspendCallbackResponse
Sourcefn from_wire_ref(
wire: &SysSuspendCallbackResponse,
) -> SysSuspendCallbackResponse
fn from_wire_ref( wire: &SysSuspendCallbackResponse, ) -> SysSuspendCallbackResponse
Converts the given reference to this type.
Sourceimpl Hash for SysSuspendCallbackResponse
impl Hash for SysSuspendCallbackResponse
Sourceimpl Ord for SysSuspendCallbackResponse
impl Ord for SysSuspendCallbackResponse
Sourcefn cmp(&self, other: &SysSuspendCallbackResponse) -> Ordering
fn cmp(&self, other: &SysSuspendCallbackResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for SysSuspendCallbackResponse
impl PartialEq for SysSuspendCallbackResponse
Sourcefn eq(&self, other: &SysSuspendCallbackResponse) -> bool
fn eq(&self, other: &SysSuspendCallbackResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for SysSuspendCallbackResponse
impl PartialOrd for SysSuspendCallbackResponse
impl StructuralPartialEq for SysSuspendCallbackResponse