SysSuspend

pub struct SysSuspend;
The type corresponding to the SysSuspend protocol. Servers that implement this protocol can be registered to the platform bus to receive callbacks on why the platform bus is suspending.