#[repr(C)]pub struct FirmwareBlob {
pub vmo: Vmo,
pub length: Uint64,
}Expand description
The wire type corresponding to FirmwareBlob.
Fields
vmo: Vmolength: Uint64Trait Implementations
Sourceimpl Constrained for FirmwareBlob
impl Constrained for FirmwareBlob
Sourceimpl Debug for FirmwareBlob
impl Debug for FirmwareBlob
Sourceimpl<___D> Decode<___D> for FirmwareBlobwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for FirmwareBlobwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<FirmwareBlob, ___E> for FirmwareBlobwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<FirmwareBlob, ___E> for FirmwareBlobwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<FirmwareBlob>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<FirmwareBlob>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1> Encode<FirmwareBlob, ___E> for FirmwareBlob<T0, T1>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Vmo, ___E>,
T1: Encode<Uint64, ___E>,
impl<___E, T0, T1> Encode<FirmwareBlob, ___E> for FirmwareBlob<T0, T1>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Vmo, ___E>,
T1: Encode<Uint64, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<FirmwareBlob>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<FirmwareBlob>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<FirmwareBlob> for FirmwareBlob
impl FromWire<FirmwareBlob> for FirmwareBlob
Sourcefn from_wire(wire: FirmwareBlob) -> Self
fn from_wire(wire: FirmwareBlob) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl IntoNatural for FirmwareBlob
impl IntoNatural for FirmwareBlob
Sourcetype Natural = FirmwareBlob
type Natural = FirmwareBlob
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for FirmwareBlob
impl Wire for FirmwareBlob
Sourcetype Narrowed<'de> = FirmwareBlob
type Narrowed<'de> = FirmwareBlob
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.