#[repr(C)]pub struct SysSuspendCallbackRequest {
pub enable_wake: bool,
pub suspend_reason: u8,
}Expand description
The wire type corresponding to SysSuspendCallbackRequest.
Fields
enable_wake: boolsuspend_reason: u8Trait Implementations
Sourceimpl Clone for SysSuspendCallbackRequest
impl Clone for SysSuspendCallbackRequest
Sourcefn clone(&self) -> SysSuspendCallbackRequest
fn clone(&self) -> SysSuspendCallbackRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for SysSuspendCallbackRequest
impl Constrained for SysSuspendCallbackRequest
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, SysSuspendCallbackRequest>,
_: <SysSuspendCallbackRequest as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, SysSuspendCallbackRequest>, _: <SysSuspendCallbackRequest as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for SysSuspendCallbackRequest
impl Debug for SysSuspendCallbackRequest
Sourceimpl<___D> Decode<___D> for SysSuspendCallbackRequestwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for SysSuspendCallbackRequestwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<___E> Encode<SysSuspendCallbackRequest, ___E> for SysSuspendCallbackRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<SysSuspendCallbackRequest, ___E> for SysSuspendCallbackRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<SysSuspendCallbackRequest, SysSuspendCallbackRequest>
const COPY_OPTIMIZATION: CopyOptimization<SysSuspendCallbackRequest, SysSuspendCallbackRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SysSuspendCallbackRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SysSuspendCallbackRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<SysSuspendCallbackRequest, ___E> for &'a SysSuspendCallbackRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<SysSuspendCallbackRequest, ___E> for &'a SysSuspendCallbackRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SysSuspendCallbackRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SysSuspendCallbackRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1> Encode<SysSuspendCallbackRequest, ___E> for SysSuspendCallbackRequest<T0, T1>
impl<___E, T0, T1> Encode<SysSuspendCallbackRequest, ___E> for SysSuspendCallbackRequest<T0, T1>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SysSuspendCallbackRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SysSuspendCallbackRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<SysSuspendCallbackRequest> for SysSuspendCallbackRequest
impl FromWire<SysSuspendCallbackRequest> for SysSuspendCallbackRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<SysSuspendCallbackRequest, SysSuspendCallbackRequest>
const COPY_OPTIMIZATION: CopyOptimization<SysSuspendCallbackRequest, SysSuspendCallbackRequest>
Sourcefn from_wire(wire: SysSuspendCallbackRequest) -> SysSuspendCallbackRequest
fn from_wire(wire: SysSuspendCallbackRequest) -> SysSuspendCallbackRequest
Converts the given owned value to this type.
Sourceimpl FromWireRef<SysSuspendCallbackRequest> for SysSuspendCallbackRequest
impl FromWireRef<SysSuspendCallbackRequest> for SysSuspendCallbackRequest
Sourcefn from_wire_ref(wire: &SysSuspendCallbackRequest) -> SysSuspendCallbackRequest
fn from_wire_ref(wire: &SysSuspendCallbackRequest) -> SysSuspendCallbackRequest
Converts the given reference to this type.
Sourceimpl IntoNatural for SysSuspendCallbackRequest
impl IntoNatural for SysSuspendCallbackRequest
Sourcetype Natural = SysSuspendCallbackRequest
type Natural = SysSuspendCallbackRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for SysSuspendCallbackRequest
impl Wire for SysSuspendCallbackRequest
Sourcetype Narrowed<'de> = SysSuspendCallbackRequest
type Narrowed<'de> = SysSuspendCallbackRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<SysSuspendCallbackRequest>)
fn zero_padding(out_: &mut MaybeUninit<SysSuspendCallbackRequest>)
Writes zeroes to the padding for this type, if any.