#[repr(C)]pub struct UserspaceIrq {
pub irq: Uint32,
pub controller_id: Uint32,
}Expand description
The wire type corresponding to UserspaceIrq.
Fields
irq: Uint32controller_id: Uint32Trait Implementations
Sourceimpl Clone for UserspaceIrq
impl Clone for UserspaceIrq
Sourcefn clone(&self) -> UserspaceIrq
fn clone(&self) -> UserspaceIrq
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for UserspaceIrq
impl Constrained for UserspaceIrq
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, UserspaceIrq>,
_: <UserspaceIrq as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, UserspaceIrq>, _: <UserspaceIrq as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for UserspaceIrq
impl Debug for UserspaceIrq
Sourceimpl<___D> Decode<___D> for UserspaceIrqwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for UserspaceIrqwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<___E> Encode<UserspaceIrq, ___E> for UserspaceIrqwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<UserspaceIrq, ___E> for UserspaceIrqwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<UserspaceIrq, UserspaceIrq>
const COPY_OPTIMIZATION: CopyOptimization<UserspaceIrq, UserspaceIrq>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<UserspaceIrq>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<UserspaceIrq>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<UserspaceIrq, ___E> for &'a UserspaceIrqwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<UserspaceIrq, ___E> for &'a UserspaceIrqwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<UserspaceIrq>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<UserspaceIrq>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1> Encode<UserspaceIrq, ___E> for UserspaceIrq<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
T1: Encode<Uint32, ___E>,
impl<___E, T0, T1> Encode<UserspaceIrq, ___E> for UserspaceIrq<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
T1: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<UserspaceIrq>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<UserspaceIrq>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<UserspaceIrq> for UserspaceIrq
impl FromWire<UserspaceIrq> for UserspaceIrq
Sourceconst COPY_OPTIMIZATION: CopyOptimization<UserspaceIrq, UserspaceIrq>
const COPY_OPTIMIZATION: CopyOptimization<UserspaceIrq, UserspaceIrq>
Sourcefn from_wire(wire: UserspaceIrq) -> UserspaceIrq
fn from_wire(wire: UserspaceIrq) -> UserspaceIrq
Converts the given owned value to this type.
Sourceimpl FromWireRef<UserspaceIrq> for UserspaceIrq
impl FromWireRef<UserspaceIrq> for UserspaceIrq
Sourcefn from_wire_ref(wire: &UserspaceIrq) -> UserspaceIrq
fn from_wire_ref(wire: &UserspaceIrq) -> UserspaceIrq
Converts the given reference to this type.
Sourceimpl IntoNatural for UserspaceIrq
impl IntoNatural for UserspaceIrq
Sourcetype Natural = UserspaceIrq
type Natural = UserspaceIrq
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for UserspaceIrq
impl Wire for UserspaceIrq
Sourcetype Narrowed<'de> = UserspaceIrq
type Narrowed<'de> = UserspaceIrq
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<UserspaceIrq>)
fn zero_padding(out_: &mut MaybeUninit<UserspaceIrq>)
Writes zeroes to the padding for this type, if any.